@@ -9,7 +9,7 @@
 */
 
 /* ====================================================================
- * Copyright (c) 1998-1999 Ralf S. Engelschall. All rights reserved.
+ * Copyright (c) 1998-2000 Ralf S. Engelschall. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -131,7 +131,7 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
         if (sc->szPublicCertFile[0] == NULL) {
             ssl_log(pServ, SSL_LOG_ERROR,
                     "Init: Server %s should be SSL-aware but has no certificate configured "
-                    "[Hint: SSLCertifcateFile]", cpVHostID);
+                    "[Hint: SSLCertificateFile]", cpVHostID);
             ssl_die();
         }
         algoCert = SSL_ALGO_UNKNOWN;
